package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````(;``````````0```````
M`+%@``````!``#@`"0!``!<`%@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M7`````````)<`````````EP`````````&``````````8``````````$````!
M````!0```````````````````````````````````````*'D````````H>0`
M```````0``````$````&````````J\@```````"[R````````+O(````````
M!+@````````%$````````!```````@````8```````"KV````````+O8````
M````N]@````````!X`````````'@``````````@````$````!`````````(X
M`````````C@````````".``````````D`````````"0`````````!&1TY5``
M```$````````FX@```````";B````````)N(`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*O(````````N\@`````
M``"[R`````````0X````````!#@``````````0````0````4`````T=.50!O
MQITA+'SCJI.O-%$I-ISM5>6/K"]L:6(O;&0M;75S;"US,SDP>"YS;RXQ````
M```````1````1`````0````(@`1`!0`0$""$`(:`!!``*`D$``D"`*&""`($
MND$8@(@`````````1````$@```!,````30```%0```!5````5@````````!8
M````60````````!:````6P```%T``````````"U'WLX?W\5N?)I_:@[OT^NV
MF\4N#O&-N`[D_R!\U&35'%AQV6^+`;*;PT^8+#_EPH?7^D)@;*'Z?)+CN@'&
M1^/2/,-59LRO9]-P!XCLU45#[=MB,\PEC!6;G*E_"@*GX%">&FM)^^"C````
M```````````````````````````````````````#```(````````&!``````
M`````````GD2`````````````````````````````8T2````````````````
M`````````````$L2`````````````````````````````F@2````````````
M`````````````````6$2`````````````````````````````#T2````````
M`````````````````````1(2`````````````````````````````=`2````
M`````````````````````````*,2`````````````````````````````*PB
M`````````````````````````````2H2````````````````````````````
M`;42`````````````````````````````E82````````````````````````
M`````7(2`````````````````````````````/42````````````````````
M`````````G$2`````````````````````````````K@A````````````````
M`````````````#<2`````````````````````````````K<1````````````
M`````````````````:@1`````````````````````````````1D2````````
M`````````````````````C\2`````````````````````````````%L2````
M`````````````````````````>\2`````````````````````````````KD1
M`````````````````````````````)02````````````````````````````
M`A82`````````````````````````````!\@````````````````````````
M`````3\2`````````````````````````````-8@````````````````````
M`````````&,2`````````````````````````````/`2````````````````
M`````````````%,2`````````````````````````````$02````````````
M`````````````````!`2`````````````````````````````@T2````````
M`````````````````````H`2`````````````````````````````8$2````
M`````````````````````````'(@`````````````````````````````J$2
M`````````````````````````````B\2````````````````````````````
M`=P2``````````````````````````````$2````````````````````````
M`````^(2`````````````````````````````B$2````````````````````
M`````````ID2``````````````````````````````D1````````````````
M`````````````?T2`````````````````````````````&02````````````
M`````````````````ET2`````````````````````````````!@2````````
M`````````````````````/L2`````````````````````````````-$2````
M`````````````````````````4X6`````````````````````````````J@2
M`````````````````````````````H<2````````````````````````````
M`(X2`````````````````````````````)P2````````````````````````
M`````&D2`````````````````````````````3$2````````````````````
M`````````DH2`````````````````````````````0P2````````````````
M`````````````+L@`````````````````````````````<82````````````
M`````````````````),2`````````````````````````````<L2````````
M`````````````````````VH2```*````````-\@````````&/````W<2```*
M````````0'``````````T````I02```*````````'S`````````"@````:(2
M```+````````6N@``````````@```NX2```*````````*E``````````!@``
M`^X2```(````````&!```````````@```R,2```*````````*E@````````"
M;````S@2```*````````/@@````````"9@```X,0```4````````P(``````
M`````````PD2```*````````,_@`````````@````S`2```*````````-'@`
M````````=````TX2```*````````*/``````````.````U\2```*````````
M6%`````````!F````X\2```*````````-P@`````````P````[X0```4````
M````P-@``````````````\,2```*````````+,@`````````-@```U82```*
M````````(>``````````/````Q<2```*````````+0`````````!8@```O\1
M```3````````P'@`````````"````[<0```4````````P(``````````````
M`X@2```*````````(;```````````````^L2```*````````5^``````````
M;````]`2```*````````-M@`````````+````Z$2```*````````*2@`````
M```!)````_02```*````````6>@`````````_````N$2```*````````+F@`
M```````%C`!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G
M:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`=6YL:6YK`&UE;6UO=F4`
M<W1R;F-M<`!S=')R8VAR`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E
M<E1-0VQO;F5486)L90!O<&5N`'9F<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?
M7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!M96UC<'D`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N
M97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?
M=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N
M`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S;G!R:6YT
M9@!R96%D9&ER`'-T<F-P>0!S=')T;VL`7U]L:6)C7W-T87)T7VUA:6X`<W!R
M:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`7U]E;G9I<F]N`&QI8G!E<FPN
M<V\`;&EB8RYM=7-L+7,S.3!X+G-O+C$`<&%R7VEN:71?96YV`'!A<E]C=7)R
M96YT7V5X96,`;7E?<&%R7W!L`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`
M<&%R7V9I;F1P<F]G`'!A<E]D:64`6%-?26YT97)N86QS7U!!4E]"3T]4`'AS
M7VEN:70`7W-T87)T7V,`<VAA7W5P9&%T90!P87)?;6MT;7!D:7(`<&%R7V-L
M96%N=7``7U]B<W-?<W1A<G0`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`%]E9&%T80!?96YD`'!A<E]B87-E;F%M90!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!S:&%?:6YI=`!S:&%?9FEN86P`+W5S<B]L
M:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````````````+O(``````````P`
M```````B^````````+O0``````````P````````BD````````+^@````````
M``P````````8$````````+_0``````````P````````?,````````+_@````
M``````P```````!:Z````````,````````````P```````#``````````,`8
M``````````P```````!=]````````,`@``````````P```````!;4```````
M`,`P``````````P```````!;\````````,`X``````````P```````!;]```
M`````,!```````````P```````!=Z````````,!(``````````P```````!;
M5@```````,!0``````````P```````!=\````````,!@``````````P`````
M``!=V````````,!H``````````P```````!=W@```````,!X``````````P`
M``````!=^@```````+^(````!@````H``````````````````+^0````"P``
M``H``````````````````+^8````%0````H``````````````````+^H````
M&@````H``````````````````+^P````'0````H``````````````````+^X
M````'P````H``````````````````+_`````*`````H`````````````````
M`+_(````*@````H``````````````````+_8````*P````H`````````````
M`````+_H````,`````H``````````````````+_P````-P```#@`````````
M`````````+_X````0`````H``````````````````+W0`````@````L`````
M`````````````+W8`````P````L``````````````````+W@````!`````L`
M`````````````````+WH````!0````L``````````````````+WP````!P``
M``L``````````````````+WX````"`````L``````````````````+X`````
M"0````L``````````````````+X(````"@````L``````````````````+X0
M````"P````L``````````````````+X8````#`````L`````````````````
M`+X@````#0````L``````````````````+XH````#@````L`````````````
M`````+XP````#P````L``````````````````+XX````$`````L`````````
M`````````+Y`````$0````L``````````````````+Y(````$P````L`````
M`````````````+Y0````%@````L``````````````````+Y8````%P````L`
M`````````````````+Y@````&`````L``````````````````+YH````&0``
M``L``````````````````+YP````&P````L``````````````````+YX````
M'`````L``````````````````+Z`````'0````L``````````````````+Z(
M````'@````L``````````````````+Z0````(`````L`````````````````
M`+Z8````(0````L``````````````````+Z@````(@````L`````````````
M`````+ZH````(P````L``````````````````+ZP````)`````L`````````
M`````````+ZX````)0````L``````````````````+[`````)@````L`````
M`````````````+[(````)P````L``````````````````+[0````*0````L`
M`````````````````+[8````+`````L``````````````````+[@````+0``
M``L``````````````````+[H````+@````L``````````````````+[P````
M+P````L``````````````````+[X````,0````L``````````````````+\`
M````,@````L``````````````````+\(````,P````L`````````````````
M`+\0````-`````L``````````````````+\8````-0````L`````````````
M`````+\@````-@````L``````````````````+\H````.`````L`````````
M`````````+\P````.0````L``````````````````+\X````.@````L`````
M`````````````+]`````.P````L``````````````````+](````/`````L`
M`````````````````+]0````/0````L``````````````````+]8````/@``
M``L``````````````````+]@````/P````L``````````````````+]H````
M0`````L``````````````````+]P````00````L``````````````````+]X
M````0@````L``````````````````+^`````0P````L``````````.OO\'``
M)+D$``^G^_]@XP#P```DZ^_Q$``$!_[C$/`X`"3`$```4L/2!_`P$`CC$!`0
M``0'\0<`!P`'`,`0``!2PN,0$```!`?Q#1#C$!`,`!3`]/___^4`````P!``
M`%*VXQ`0```$!_$-$.,0$`P`%,#T____U0```!C`$```4JKC$!````0'\0T0
MXQ`0#``4P/3____%````,,`0``!2GN,0$```!`?Q#1#C$!`,`!3`]/___[4`
M``!(P!```%*2XQ`0```$!_$-$.,0$`P`%,#T____I0```&#`$```4H;C$!``
M``0'\0T0XQ`0#``4P/3___^5````>,`0``!2>N,0$```!`?Q#1#C$!`,`!3`
M]/___X4```"0P!```%)NXQ`0```$!_$-$.,0$`P`%,#T____=0```*C`$```
M4F+C$!````0'\0T0XQ`0#``4P/3___]E````P,`0``!25N,0$```!`?Q#1#C
M$!`,`!3`]/___U4```#8P!```%)*XQ`0```$!_$-$.,0$`P`%,#T____10``
M`/#`$```4C[C$!````0'\0T0XQ`0#``4P/3___\U```!",`0``!2,N,0$```
M!`?Q#1#C$!`,`!3`]/___R4```$@P!```%(FXQ`0```$!_$-$.,0$`P`%,#T
M____%0```3C`$```4AKC$!````0'\0T0XQ`0#``4P/3___\%```!4,`0``!2
M#N,0$```!`?Q#1#C$!`,`!3`]/___O4```%HP!```%("XQ`0```$!_$-$.,0
M$`P`%,#T___^Y0```8#`$```4?;C$!````0'\0T0XQ`0#``4P/3___[5```!
MF,`0``!1ZN,0$```!`?Q#1#C$!`,`!3`]/___L4```&PP!```%'>XQ`0```$
M!_$-$.,0$`P`%,#T___^M0```<C`$```4=+C$!````0'\0T0XQ`0#``4P/3_
M__ZE```!X,`0``!1QN,0$```!`?Q#1#C$!`,`!3`]/___I4```'XP!```%&Z
MXQ`0```$!_$-$.,0$`P`%,#T___^A0```A#`$```4:[C$!````0'\0T0XQ`0
M#``4P/3___YU```"*,`0``!1HN,0$```!`?Q#1#C$!`,`!3`]/___F4```)`
MP!```%&6XQ`0```$!_$-$.,0$`P`%,#T___^50```EC`$```48KC$!````0'
M\0T0XQ`0#``4P/3___Y%```"<,`0``!1?N,0$```!`?Q#1#C$!`,`!3`]/__
M_C4```*(P!```%%RXQ`0```$!_$-$.,0$`P`%,#T___^)0```J#`$```46;C
M$!````0'\0T0XQ`0#``4P/3___X5```"N,`0``!16N,0$```!`?Q#1#C$!`,
M`!3`]/___@4```+0P!```%%.XQ`0```$!_$-$.,0$`P`%,#T___]]0```NC`
M$```44+C$!````0'\0T0XQ`0#``4P/3___WE```#`,`0``!1-N,0$```!`?Q
M#1#C$!`,`!3`]/___=4```,8P!```%$JXQ`0```$!_$-$.,0$`P`%,#T___]
MQ0```S#`$```41[C$!````0'\0T0XQ`0#``4P/3___VU```#2,`0``!1$N,0
M$```!`?Q#1#C$!`,`!3`]/___:4```-@P!```%$&XQ`0```$!_$-$.,0$`P`
M%,#T___]E0```WC`$```4/KC$!````0'\0T0XQ`0#``4P/3___V%```#D,`0
M``!0[N,0$```!`?Q#1#C$!`,`!3`]/___74```.HP!```%#BXQ`0```$!_$-
M$.,0$`P`%,#T___]90```\#`$```4-;C$!````0'\0T0XQ`0#``4P/3___U5
M```#V,`0``!0RN,0$```!`?Q#1#C$!`,`!3`]/___44```/PP!```%"^XQ`0
M```$!_$-$.,0$`P`%,#T___]-0``!`C`$```4++C$!````0'\0T0XQ`0#``4
MP/3___TE```$(,`0``!0IN,0$```!`?Q#1#C$!`,`!3`]/___14```0XP!``
M`%":XQ`0```$!_$-$.,0$`P`%,#T___]!0``!%#`$```4([C$!````0'\0T0
MXQ`0#``4P/3___SU```$:,`0``!0@N,0$```!`?Q#1#C$!`,`!3`]/___.4`
M``2`P!```%!VXQ`0```$!_$-$.,0$`P`%,#T___\U0``!)C`$```4&KC$!``
M``0'\0T0XQ`0#``4P/3___S%```$L,`0``!07N,0$```!`?Q#1#C$!`,`!3`
M]/___+4```3(P!```%!2XQ`0```$!_$-$.,0$`P`%,#T___\I0``!.#`$```
M4$;C$!````0'\0T0XQ`0#``4P/3___R5```$^,`0``!0.N,0$```!`?Q#1#C
M$!`,`!3`]/___(4```40`````.MO\#``)./P_SC_<>,P\*@`).-`\*``)%`@
M\+1!0/"@03#PJ$$@\+2R3P"PZ[L`(``-LD\`L=('\,"P*,#E___]X,1(``!0
M,\0H``!0"+D$`#3`Y?___Q7$&```4`B5`!``IX0`ML`P``!0+>-0,```!%B@
M\+3LF@`$`-BY%`#IXV6P```$ZRX``P`-E@-DBJ>J``/`Y?___U3C$/"H``3`
M,```'P#C`!````3C,"`(`"3C`"```"2Y!`!2Q"L``%!JP$```![QXT!0&``D
MQ"@``%`]XR!0$``D6)#PM.R<`,4!?NSI``,`V.P)__\`V$$P$`BG*``$IP$`
M`:=T`(*(```!N10`0NP2``$`V.OD``,`#;D4`&'C0#````3C3E```"3K%@`#
M``WC8#`(``3C85```"2G*@`"ISL`$*<&_^/L:0`#`-BY%`"6N10`2NNI``,`
M#4$J4`"G:0``Y4@@````P#````/RQ"@``%`;P.7___SF["@`5`!^Q"@``%`2
M06#PO,#E___]^[D$`#:Y!`"2P"```!UOP.4```$W["@`1P!\Q"@``$_]P.7_
M__[XP.7___ZUU0?PP+`HIW0`6;D$`"GK;_#X``0'_L#E___^%\0K``!/YNPH
M`$X`?,#E___\7L`P``!/;>,@,```!.-"L```!)(`24:G]/\XXS`P```$XS!0
M(``DIR@`!4$P$!#L+O]V8':G]/^4Q"@``$_!P.7___U,I_3_J<!0``!/M>,@
M4````J>$``?`Y0``#X&G]/^QN00`-L`@```<Z\#E````V\0K``!/H.PH_Z0`
M?*?T_^VG:``$I_3_;L#E___\5J<I``'`Y?___?&Y!``OP#`````2XS`P```8
MI_O_8*<)``#C`/```"3`]`````D'!P<'``":``<'!P?K;_`P`"1!0"`(X_#_
M6/]QQ&@``$[XY4CPH```Q%@``$[2XS`@!``4Q"@``$[DP.7___W?ZV_PV``$
M!_X'!P<'P!```$\PP"```$\M[!(`"H!DQ!@``$['[!@`!`!\!_$'_@<'!P<'
M!\`0``!/',`@``!/&;D)`!+K`0`#``KK,0`_``RY"``PZS,``0`*[#@`#0!\
MQ!@``$ZB[!@`!P!\P"```$\`!_$'_@<'!P<'!^N_\%@`),"P``!.]>/P_V#_
M<94`L`"G=``CP!```$YSXQ`0```"IX0`",0H``!.H\#E___[1L#E____K<`@
M``!.<N,0(````J>$``C`(```/,+`Y?___!62`;``Z[_P^``$!_X'!P<'P!``
M`$Z`XQ`0```"IX0`%^OO\'``),`P``!.O>/P_V#_<<`@```\H\#E___]QNOO
M\1``!,#T____CL#T____B^MO\#``),08``!.->/P_V#_<>-P$````J>$`%.Y
M!`""N00`8^,`(```E+D$`)*5`"``IX0`2NP(``P]?D&0D`'C`)```)25`)``
MIW3_]AN8XZ!P```"IX0`'[D4`)FY!`"WN00`2;D$`#BY!``JP.7___OS["8`
M"0!^02F@`)4](`"GA``/0;"P"..@L````J=T_^FY!``JZV_PT``$!_Y!J:`!
MN>EP.[D$`"KK0P`#``I00&``ZV_PT``$!_ZGJ0``I_3_Z:>8``"G]/_#!P?K
MK_!0`"3C\/[(_W&R3P"PN00`HNN[`"``#4$P\*"R3P"QT@?Q,+`HP.7___N.
M["8`(0!^&!*G.$``6"#PN,`K``#P`.PC``B`=J4/H`#L(``38':Y!``JISD`
M`L#E___\=!`2IQK__X@0`!^G]``$IQ@``-4'\3"P*+D4`"&G=``&ZZ_QB``$
M!_[`Y?__^MWKC_!``"3C\/[(_W&R3P"`ZX@`(``-LD\`@=('\3"`*.PH``D`
M?+D$`+*5`"``IW0`"]4'\3"`**=T`)'KC_%X``0'_L#E___[R+D$`)+L*/_R
M`'RY!``IP.7___J.["@`80!\0:`@$Y4N(!.G=``&E0"@`:>$__"5+B`3IX0`
M7J<(``"Y!``ZN00`&Z=)``"R7@!#IQ3__KD)`$JG*0``LEX`(:<4__ZY"0`K
M&B2G*@`"N10`(L#E___Z+[D$`%K`,```&MBY!`"BN00`2\#E___[L[D$`"I!
M,/"@P.7___O,["@`#?]^6`#PN*=80`#`"P``\`#L!0`K@':Y!``JP.7___L*
MN00`*L#E___\M;D$`"G`Y?__^C#L)O^E`'RY!``IP.7___PXN00`*\#E___Z
M$Z?T_W^5+J`!IW3_HI4`H`*GA/^(I_3_G+D$`"K`Y?___UBG]/_8P.7___HM
MZV_P,``DX_#_2/]QLD\`8.MF`"``#;)/`&&5/3``T@?PL&`H0:`P`;GB<*.G
M"```N00`&J>)``"Y!`"RLEX`@:<4__Y!,/"LN0D`BL#E___^>NPH`)<`?*<(
M``"GV0``N00`XK)>`-ZG%/_^N0D`TNR-`';`9>,`\*P`%,38``!,FNMP``,`
M#>,@L```E+D$`$N5`+``IW0`#:?T`.9!0$`!XR!```"4E0!``*>$``7L)O_W
M/7ZY"0!+N10`E$$HD`*Y!`"'XX#0```(P.7___ETXR"````D["@`.0!\XS#0
M```$XU"P``"0X^<P```$0E#@`$%PL`$8!>Q6`!``?*?T`#SC$'```)!"$+`!
M07!P`1@![!@`,@!\0@#PH+D$`+Z5/?"@0>#@`:=T_^V2/;``I]D``.--H```
MD$)-L`&GVP`![$;_^0!\U0?PL&`HIW0`E>MO\.@`!`?^IYD``..)H```D$*)
M(`"GFP`![(;_^0!\I_3_Z[D$`+ZG]/_9Q-@``$P8XW#0```$XQ!P```"IX0`
M;KD$`$>GF```&"FGF@`!04!`".,P0````J=T__BG*@`#N10``NL@``,`#<`P
M``!,@.,0,```$J=T`#;`4```3'CE3%````'`Y?__^.SC(/"@`"3L*/^Q`'RY
M%`#IN00`-^M^``,`#;D$`$?`Y?__^$KC(/"@``3C(-```"10D/"LXU#PH``$
MIYH``;D4`)GK.0`#``U!$U``Y4@0````I_3_*KD$`#*Y!``GP.7___G*XR#P
MH``DXR#0```D["C_?`!\N10`2>MT``,`#:?T_]BGF0``I_3_*J<I`!"GF```
MI_3_I<#E___X[>MO\#``),`0``!+N>/P_UC_<>.P$```!,!0```Y<,1(``!+
MF<`P```9.;)/`*#KJ@`@``VR3P"AXRN@```$P&```!J,P.7___D8N00`5N5(
M\*```,!````*GN,KH```!,`P```9*<#E___X5^MO\-@`!`?^!P<'![)/`"#`
M$```2W[K,@`@``WC0!````2R3P`QP%```#DSXR0P```$Q$@``$M9P#```!CY
MP/3___CEZV_P,``DX_#P`/]QXP#_^``@X_#P`/]QXP#_^``@X_#_4/]QXP#P
MJ``@XQ#PJ`)QLD\`D.N9`"``#;)/`)%!L/"FT@<0`)`HP.7___>NP&```!CE
MN00`4L!````8XKD$`"NG.1`!P.7___>/["@`5?]^N00``N.`\*<!<;D$`"NY
M!``X[``0`"!QITD0`,#E___WN[D$`&+L)``_`'ZG*@`!N10`(L#E___W[[D$
M`*+L*``S`'RY%`"V["@`!Z!EN>BP,KEA0(/LJ``A(&6Y!``XN00`2[D$`"KL
ML!`!(''`Y?__]W)!6Z``D@!0`./@\*@"<=4'X`"0**=T`!*Y!``JZV_PX`($
M!_ZYZ+!(N6%`I*?T_]ZGJ0``I_3_ZL#E___X`P<'!P?`]/___VP'!^MO\#``
M)./P\`#_<>,`__@`(./P_KC_<>,`\4``(.,0\4`!<;D$`+*Y!`"3LD\`<$$P
M\*SK=P`@``W`(```&&"R3P!QT@<0`'`HP.7___Q+ISD`+[D$`**Y!``KP.7_
M__FL["@`&0!\P"```!A.N00`.\#E___]E[D$`"OC@/%``7'5!X``<"BG=`#O
MZV_Q>`$$!_ZY!``IP.7___BNP#```!@ZP.7___B(N00`4NPH_]T`?$&0\4!!
M@/"PE0!0`*>$`)CLJ``/`'RG"```N00`-;D$`"JR70`RIQ3__J>$`'BG"```
MITD``+D$`&6R7@!&IQ3__KGI4"3C$$___W'L40`WH&6YZ5`!IP$``:>$``Z5
M+Q``IW0`()(`$`#C$!___W'L40`9@&3KX``!``R5+Q``IW0`$9(`$`#K+Q__
M_U6G=``*ZP`?__]2XQ`?_O]QI^?_[Z<(``"G*0``N00`-;)>`".G%/_^N0D`
M):<(``"G20``N00`:Z?I#_^R7@!&IQ3__KD)`$M!!"`![`[_;2!EX[#PH``D
MN00`*<!@```7N\!````8,J<Y$`#`Y?__]E.G6!``IRH``>PE`"C`=Z?T``&5
M`*`!IW0`&L`P```7HJ<I``#`Y?__]^ZY!`!2["C_0P!\E0!0`*=T_VSLJ``'
M`'R5+J``IX3_YJ<I``'`4```%WNG]/^SN00`.+D$`"G`Y?__^%#L)O_:`'Y8
M$/#(I3^``,`;``#P`.P3_]!@=KD$`"FG.0`!P.7___A<[";_Q@!^N00`.<`@
M```77,#E___\I[D$`"G`Y?__]\RG]/\-P.7___;'!P<'!^N_\%@`)*<Y`"^Y
M!`"RX_#_8/]QP.7___;801`@`;D"`"*Y!``KN>)P(>N_\/@`!,#T___WJ@<'
MZZ_P4``DX_#P`/]QXP#_^``@X_#_6/]QXP#PH``@LD\`L.,0\*`!<>N[`"``
M#;)/`+'2!Q``L"CL*`!K`'RY!``RE0`@`*>$`&2G"```ITD``+)>`$*G%/_^
MIPD0`+D)`$.G2P`![$``=R!E0:#PH+D$`"K`Y?__]6RG"```ISD``+D$`%JR
M7@`UIQ3__N,0/___<>P:`!_`9;GIH.&G$0`!IW0`1^M.``$`#)4O$`"G=``1
MD@`0`.LO'___5:=T``KK`!___U+C$!_^_W&G1__ON00`*J<Y`"_`Y?__]EGL
M*``7`'SL*@`S(&6Y!``JP.7___<NXS#PH`%QU0<P`+`HIW0`+>NO\/@!!`?^
MXR#PH`%QU0<@`+`HIW0`(<`@```6F>NO\/@!!,#T___W$94O$`"G=/_/D@`0
M`.,0'___<>P:_[)@9*?T_\62`"``I_3_SJ<I``"G]/_/P.7___7X!P<'!P<'
MZZ_P4``DX_#_4/]QLD\`H.NJ`"``#;)/`*%!L/"DT@?PJ*`HN00`.\`@```6
M;\#E___Z4>PH`"X`?.-`\*0`%,0H``!(@.L4``,`#>,0(```".-0$`@`!.-0
M$```).Q8_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"```!9$P.7_
M__HF[";_V`!\N00`.\`@```6/L#E___Z&^PH`"X`?.,0\*0`%,18``!(2NOA
M``,`#>/@4```".,`X`@`!.,`X```).P(_^,`?.,PX!``!.,PX`@`)$'@X`CL
M-O_X`'RY!``[P"```!83P.7___GP[";_V`!\N00`.\`@```6#,#E___YY>PH
M`"X`?.-0\*0`%,3H``!(%.M%``,`#>-`X```".,P0`@`!.,P0```).PX_^,`
M?.,@0!``!.,@0`@`)$%`0`CL)O_X`'RY!``[P"```!7AP.7___FZ[";_V`!\
MN00`.\`@```5V\#E___YK^PH`"X`?.,P\*0`%,0H``!'WNL3``,`#>,0(```
M".-`$`@`!.-`$```).Q(_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[
MP"```!6PP.7___F$[";_V`!\N00`.\`@```5J<#E___Y>>PH`"X`?.,0\*0`
M%,1(``!'J.M1``,`#>-00```".,`4`@`!.,`4```).P(_^,`?./@4!``!./@
M4`@`)$%04`CLYO_X`'RY!``[P"```!5^P.7___E.[";_V`!\N00`.\`@```5
M>\#E___Y0^PH`"X`?.-`\*0`%,18``!'<NLT``,`#>,P4```"./@,`@`!./@
M,```).SH_^,`?.,@,!``!.,@,`@`)$$P,`CL)O_X`'RY!``[P"```!50P.7_
M__D8[";_V`!\N00`.\`@```5'<#E___Y#>PH`"X`?./@\*0`%,0H``!'/.L>
M``,`#>,0(```".,P$`@`!.,P$```).PX_^,`?.,`$!``!.,`$`@`)$$0$`CL
M!O_X`'RY!``[P"```!3RP.7___CB[";_V`!\N00`.\`@```5%<#E___XU^PH
M`"X`?.,0\*0`%,0X``!'!NM!``,`#>-`,```".,`0`@`!.,`0```).P(_^,`
M?.-00!``!.-00`@`)$%`0`CL5O_X`'RY!``[P"```!3JP.7___BL[";_V`!\
MN00`.\`@```4Y,#E___XH>PH`"X`?.,P\*0`%,1(``!&T.OC``,`#>/@0```
M".-0X`@`!.-0X```).Q8_^,`?.,@X!``!.,@X`@`)$'@X`CL)O_X`'RY!``[
MP"```!2YP.7___AV[";_V`!\N00`.\`@```4L\#E___X:^PH`"X`?.-0\*0`
M%,3H``!&FNL5``,`#>,0X```".,@$`@`!.,@$```).PH_^,`?.,`$!``!.,`
M$`@`)$$0$`CL!O_X`'RY!``[P"```!2(P.7___A`[";_V`!\N00`.\`@```4
M2L#E___X->PH`"X`?.,0\*0`%,0H``!&9.LQ``,`#>,P(```".,`,`@`!.,`
M,```).P(_^,`?.-`,!``!.-`,`@`)$$P,`CL1O_X`'RY!``[P"```!0?P.7_
M__@*[";_V`!\N00`.\`@```43,#E___W_[D$`#+L*``)`'S`(```%#?`Y?__
M^52Y!``[P"```!1"P.7___?LN00`,NPH``D`?,`@```40,#E___Y0;D$`#O`
M(```%#[`Y?__]]FY!``R["@`&@!\P"```!/>P.7___DNU0?PJ*`HIW0`(\`P
M```4.<`@```3\.NO\0``!,#T___Y';D$`#O`(```%"+`Y?__][6Y!``R["C_
MY0!\P"```!/HP.7___D*I_3_W,#E___S+P<'!P?KO_!8`"3`(```$]CC\/]0
M_W&R3P"P03#PI.N[`"``#;)/`+'2!_"HL"C`Y?__]XOL*``A`'Q#$"``&"'`
M)P```#"YA``"N0,`,*<1`/_K4P`_``RG2```N?*`5-4'\*BP*+D4`"6G=``*
MZ[_Q"``$!_ZG6```I_3_\\#E___R[6``\(!@(/"(8$#PD&!@\)CK/_`8`"3$
M&```1:WC\/\X_W&Y!``R00#Q:+)/`"!!4/#(ZT(`(``-LD\`0>,@$```!-('
M\,!`*.,`\+``).-0\+@`).5(\*```>5(\*@``$%`\*#`Y?__]0BG*0#_P.7_
M__13!P<'!^N/\$``)./@\`#P<>/P\`#_<>,`__@`(+DA`/ZG)/_XN00`_N/P
M_U#_<>,`\*@`(.,0\*@0<:<Y``"Y!`""LD\`H*=)``+KJ@`@``VR3P"A0;#P
MH-('$`"@*,#E___R<<`Q__\``.R2__\`V>P),(``5;D$`""G"___N8$``Z<+
M``&Y`@"9N>*@`KD)`)#LE`"*`'RY!``YN00`**=)``#`Y?__\D[L*`"8_WRY
M!``[N00`*,!!``$`",#E___RX>PH`(7_?KD4`$+L3`!C!WWC%+_X_W'L&P!=
M0&7L43Z_`%7$Z```11OCX!```""GA`!HXQ`?__]Q[!L`3$!E[%@`)`!\[%@`
M%@%\[%@`"P)\X^`0```@IX0`5.,0'___<>/@$```(*>$`$SC$!___W'CX!``
M`""GA`!$XQ`?__]Q[!L`*$!EX^`0```@IX0`.>,@'___<;D$`!+CX"```""G
MA``OXQ`O__]QX^`0```@IX0`)^,0+_[_<>/@+_[_(*>$`!_C$"_]_W'L&__>
MH&7"E``!``#``?__``#LD/]\8&2G*?__XX#PJ!!QU0>``*`HIW0`&.N/\/`0
M!`?^N>FP(;D(`"FG]/_PP"```!*ZP.7___[<P"```!*MP.7___[6P.7___&]
MZ^_P<``DX_#_8/]QP.7___%$P.7___+1["@`!@!\XR`@```$Z^_Q$``$!_X'
M!P<'ZV_P,``DX_#_4/]QLD\`H+D$`++KJ@`@``U!,/"DLD\`H<`@```2B-('
M\*B@*,#E___V`>PH``D`?+D$`&*5`"``IW0`$M4'\*B@**=T`#>Y!``[P"``
M`!)OZV_PX``$P/3___=(IP@``+D$`!NY!``VITD``+)>`$.G%/_^N0D`1J<I
M``"R7@`AIQ3__KD)`"M!(D`"P.7___$'N00`2\!0```1X;D$`++`,```$E?`
MY?__\HJG]/_(P.7___%%ZV_P,``DX_#^(/]QLD\`<.MW`"``#;)/`''`$```
M1!/2!_'8<"C2#_"X$!#2!_#($"#2+_#H$"C2#_#0$%C2!_#@$&A!D/"TN00`
MTKD$`#G`(```$9W`Y?__]8WL*``)`'RY!`"RE0`@`*=T`DC`Y?__\)O`Y?__
M\BCL*`$,`'SC@"````*GA`$&IP@``*<I``"Y!``XLEX`(Z<4__ZY"0`HZR(`
M`0`-IRL``<#E___PG.-`@```E+D$`+*Y!`!BE0"``*>$`!>Y!``KN18`1,`P
M```1W<#E___R%T&`@`%!L+`"XT"```"4E0"``*=T_^U!H/#PP"```!&9I_0`
M":>K``CC(*_X_P*GA``@N00`.<#E___U+[D$`(+L*/_R`'R5`"``IX3_[<#E
M___UB^PH_^@`?KD$`"C`Y?__\:6Y!`"R["8`'0!\0:#PN..PH````J>$`!65
M`+``IX0`E[D$`"O`Y?__]6[L)@""`'ZGJP`(X["@```"IW3_[Z<(``"Y!`!6
MN00`*Z<Y``"G20``LEX`,J<4__ZR7@!%IQ3__KD)`#NY"0!&&C2G.@0$N10`
MH[D$`"K`Y?__\!;C8/"@`"2Y!`""P#```!%GN00`2\!@```17\!0```0YL#E
M___QD[D$`"BG.0'`P.7___)L["8`"_]^P.7___'66``@`.P&`6<1?KD$`"A!
M,/$8P.7___"Z&++L)@`-`'Y88/$PI^A``,!K``#P`.QN`'J`=KD$`%CC0-``
M``3$B```0O+`,```$4WC((````3`Y?__\%NGJ0``U0?QV'`HIW0!YKD$`"KK
M;_(0``0'_KD$`"NGJP`(P.7___$'N00`LNPH_V<`?*?T_WRGN0``I_3_>$&@
M\-#C(*````*GA``5N00`.<#E___T9NPH``<`?)4`(`"G=``9IZL`".,@H```
M`J=T_^^G*0`-P(```!#<P.7__^^*IT@`4[D$`+*Y!`!BI_3^\\#E___PSZ>K
M``BY!`""["C_T0!\N00`$J<(``"GZ0``LEX`X:<4__ZY"0#BZRX``0`-IRL`
M`:?T_LA88/$TP.7__^]`[&+_A&!V6!#Q,*<X`<#`&P```?_L$_]Z8':Y!``J
MP.7__^].N00`.;D$`*+`(```$.W`Y?__]`JY!``R["@`V@!\XR#0```$P.7_
M__>/N00`8NPH`,\`?*<(``"G20``N00`)K)>`$*G%/_^N0D`1NQ,`!X#?KD4
M`%3`X```$,GC%6_\_W&R70#AIQ3__J=T``_L2`$5!'ZG2O_[N10`-$%#8`"5
M+T``IX0!"KD$`#G`(```$`;`Y?__\\CL*`"?`'SCD"```)3LF`"9`'[LF`"6
M,'[`,```$"S`(```#_'`Y?__]1/`Y?__[GK`````$/BY!`!BN00`2+D$`"KC
M`/"@`"3`4```#[O`,```$)7`Y?__\&6G]``JP.7___"P6$`@`*=.`!&G=``K
MP.7__^Y7P%```!#5I[H``;D4`!NY!`!BXU#PJ``DN00`2+D$`"K`4```#Y3C
M$/"@`"3`,```$'+`Y?__\#NY!``JISD!P,#E___Q%.PH_]'_?KD$`"C`Y?__
M\4RY!``ZP"````]JP.7___2ZN00`*L#E___]/:?T_L:Y!`!8N10`8.-`T```
M!,0H``!!H<`P```/WN,@(```!,#E___O"J?T_J_`Y?___2/5!_'8<"BG=`"2
MN00`*^MO\A``!,#T___ON.-@T```!*?T_S&Y!``FISD``,#E___P?+D$`-+L
M*/]D`'[`Y?__^_:Y!`!B["3_7`!\ITD``.,P;_;_<;D$`"W`Y?__[H6Y!``M
M03#QJ:=)``;`Y?__[QSL)@!?!GS`,```+QW5!3``\:FG=/\]XS!OSO]QITD`
M`+D$`"W`Y?__[F=!8/&ON00`+;D$`#:G20`HP.7__^[\["8`/RA\P.```!`G
MN00`2+D$`"J2`/'7X^#PH``DP%````[JP#````^\P.7__^^4I_3_8^/0T`@`
M`J>$_O6G"```IRD``+D$`%VR7@`EIQ3__KD)`"WL+/[G`WWCXM_\_W'`$```
M#Y2R70`>IQ3__KGB@&VG]/[8P.7__^XMP"````^)P.7___L]!P<'!^M_\#@`
M)./P_U#_<<"@``!`[K)/`+#C$*````3KNP`@``VR3P"QXY&P```$08#PI-('
M\*BP*-(`D+&0L+D$`#C`(```#J7`Y?__\G7L*``'`'R5,2``IX0`S<#E___X
M`^,@H```!..2L```!+D$`"FG60`#ITD``<`P```/8\#E___O,[D$`)+L*``?
M`'SC,"`0``3C<*````3C,#````3`0```#U#C)[````3`Y?__[?SC0)`0``3C
M,$````210#`-IW0`O.-PH```!*=9``/C)[````2G20`!P#````\VP.7__^\"
MN00`DNPH`!P`?+D$`#C`(```#C#`Y?__\ANY!`!"["@`?`!\XQ"0$``$XR>P
M```$XS`0```$P.7__^W$XZ"@```$ITD``>.:L```!,`P```/"[D$`"G`Y?__
M[G3`0```#PZY!``RN00`*<#E___MJKD$`#C`(```#?CCBK````22`("QP.7_
M__'CQ"L``$"H["@`*P!\ISD!P,#E___O@NPR``$`V.P\`!<!?^PH`!01?KD$
M`%+$N```0([$2```0(_C,+````3`(```#NS`Y?__[%C5!_"HL"BG=`!0ZW_P
MZ``$!_[$*```0';`Y?__^_?$*P``0'3L)O_/`'S`(```#L#`Y?__[#V5`"`!
MIX3_/*?T_S'`Y?__])+C![````3C4)`0``2Y!`!RXS!0```$N00`(.QX`!<`
M?+D$`$?`Y?__[3^Y!``GP.7__^]JI_3_=N,GL```!,#E___L8J?T_T#$Z```
M0#?C0.````3`Y?__[2>G]/]CP.7__^SR!P?KG_!(`"3C\/]0_W&R3P"@N00`
MLNNJ`"``#4$P\*2R3P"AP"````V.T@?PJ*`HP.7___%-["@`$P!\XQ`@``"4
M[!@`#0!^[!@`"C!^[+@`!P!\E0"P`*=T``O5!_"HH"BG=``UZY_P^``$!_ZY
M!``KP.7___80ISD`+[D$`)+`Y?__[,^Y`@`B00`@`;D$`"FYXG`@P.7__^VD
MITD`!,`P```-I<#E___M/.PF_]@`?M4'\*B@**=T``JY!``KZY_P^``$P/3_
M__&RP.7__^R)ZV_P,``DX_#\T/]QLD\`L.N[`"``#;)/`+%!$/"HT@?S*+`H
MIPD`!$%0(#CC0%````3C,%`(``3KI``@``SCH!```"3K8P`@``SC8!`0`"3`
M2@````#C0!`(`"3`.@````#C,!`8`"1!4%`0IQL`(*<'_][C,/$0``3C@/$8
M``3CH/$@``3CD/"H``3C</"P``1!0/"XIPD`0+D$`-KCX$````2Y!``>XQ!`
M,`""N8(`$[F"`!GLH2"_(57LH2`^`5;CH$!P`"2Y!``XN00`E[D$`(VG2P`(
MIP<*VN-@(`@`!.-@\*``).-`(!``!.,`(!@`!.-0\+``!+GG`)3"6EJ">9FY
M@`"6N0@`4+F"`)#CX"````3K=@`"``SLKB"_)57L=@`A'E;LKB`Z!5;L-R"_
M`%7C$/"H``2YYS#4PAI:@GF9N8``WN,0("``"+F"`-2Y"``:N>A0C;D(`!GL
MD2"_`%7L43N_)57L60`Z!5:Y"`!8ZZX``@`,[-4[OR55[*X`(1Y6XQ#PN``$
M[(H@OP!5N>>@9\(:6H)YF>QU(+\`5;F``&GLUP`Z!5:Y@@!CN0@`%.-0\,``
M!+D(`!;"6EJ">9FY"``=N0@`4^LY``(`#.PY`"$>5KF"`*/LD2"_`%7L83N_
M)56YY'`:N00`INRI`#H%5NQC(+\`5;F"`!CCT/#(``2Y"``5PMI:@GF9N0@`
M&KGH@%WKIP`"``SL@3N_)57LIP`A'E;L<2"_`%7LAP`Z!5:Y@@`ZXQ#PT``$
MN8``.<(:6H)YF;F"`#:Y"``UN>A@4;D(`#CL:B"_`%7KB0`"``SLB0`A'E:Y
M@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#PV``$N0@`-<(:
M6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E
M5;GDD#BY!`"-[(<`.@56N8(`-N,0\.``!+D(`#7"&EJ">9FY"``XN>A@4>N)
M``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%
M5KF"`#;C$/#H``2Y"``UPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_`%7LIP`A
M'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#P\``$N0@`
M-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3
M.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\/@`!+D(`#7"&EJ">9FY"``ZN>A@
M4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'
M`#H%5KF"`#;C$/$```2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7L
MB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#Q"``$
MN0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`
M5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`-N,0\1``!+D(`#7"&EJ">9FY"``X
MN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`
MK>RI`#H%5KF"`#;C$/$8``2Y"``UPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_
M`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q
M(``$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3
M(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0\2@`!+D(`#7"&EJ">9FY
M"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL<R"_`%7LTSN_)56YY)`X
MN00`C>R'`#H%5KF"`#;C$/$P``2Y"``UPAI:@GF9N0@`.+GH8%'KB0`"``SL
M:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55XQ#Q.``$N>1P.L(:6H)YF;F"
M`#:Y!`"MN0@`->RI`#H%5KGH8%&Y"``Z[&@@OP!5[-,[OR55ZZ<``@`,[-,@
M.@56[*<`(1Y6P#H`````N>>@>..`\4``!+F``'G"BEJ">9FY@@!VN>A@&+D(
M`'7K60`"``RY"`!][%D`(1Y6[)<[OR55[)<@.@56[&H@OP!5N>=0VNN#``(`
M#+F``-.Y@@#6N0@`T;D(`-FY!`"8[),`(1Y6[#T[OR55N>>0%>P](#H%5KF"
M`!?CH/%(``3C@/%0``3"JF[9ZZ'"BF[9ZZ&Y"`"FN1H`A;D:`*'L9R*_/E6Y
M"`"C[&<"(1Y6[#H[OR55N>=@&>PZ(#H%5KF"`!WL?2*_/E6Y&@"!['T"(1Y6
MN0@`@^,P\5@`!,(Z;MGKH;GG<%:Y&@`YN>>@E>P8.[\E5;D:`#GL&"`Z!5;C
MD/%@``2Y"``QPIINV>NA[-,[OR55N1H`ENS3(#H%5NQJ(K\^5>QJ`B$>5N.@
M\6@`!+GG8%?"JF[9ZZ&Y@@!8N1H`I[D:`)7L>"*_/E6Y"`"=['@"(1Y6[(D[
MOR55[(D@.@56N>=PUK/!`&CC@/%P``3"BF[9ZZ&Y&@"&L\T`9KF"`-.Y&@"M
MN0@`INQ:.[\E5>Q:(#H%5NQC(K\^5>,0\7@`!.QC`B$>5L(:;MGKH;GG8#>Y
M&@`7N8(`.>QY(K\^5;D:`(/L>0(A'E:Y"`"%N>=P5NR8.[\E5;F"`%KLF"`Z
M!5:Y&@`5XS#Q@``$N0@`&<(Z;MGKH>R:(K\^5;D:`#;LF@(A'E;LT3N_)56Y
MYY!7[-$@.@56N8(`6..@\8@`!+D:`#7"JF[9ZZ&Y"``]N1H`I^QX(K\^5>QX
M`B$>5NR#.[\E5>R#(#H%5KGG<-FSP0!XXX#QD``$PHINV>NAN1H`B;/-`)>Y
M@@#1N1H`K;D(`*GL6CN_)57L6B`Z!5;L82*_/E7L80(A'E;C$/&8``2YYV#7
MPAINV>NAN8(`T[D:`!>Y&@"-[',BOSY5N0@`A>QS`B$>5NPX.[\E5;GG<%;L
M."`Z!5:Y@@!:XY#QH``$N1H`%<*:;MGKH;D(`!.Y&@"6[#HBOSY5[-$[OR55
M[#H"(1Y6[-$@.@56N><P5^.@\:@`!+F"`%C"JF[9ZZ&Y&@"5N1H`I[D(`)WL
M>"*_/E7L>`(A'E;LB3N_)57LB2`Z!5:YYW#3L\$`:..`\;``!,**;MGKH;D:
M`(.SS0`VN8(`T;D:`*VY"`"C[%H[OR55[%H@.@56[&$BOSY5[&$"(1Y6XQ#Q
MN``$N>=@U\(:;MGKH;F"`-FY&@`7N1H`C>QY(K\^5;D(`(7L>0(A'E;LF#N_
M)56YYW!6[)@@.@56N8(`6N,P\<``!+D:`!7".F[9ZZ&Y"``9N1H`-NR:(K\^
M5>S1.[\E5>R:`B$>5NS1(#H%5KGGD%?CH/'(``2Y@@!8PJINV>NAN1H`-;D:
M`*>Y"``]['@BOSY5['@"(1Y6[(,[OR55[(,@.@56N>=PV;/!`'CC@/'0``3"
MBF[9ZZ&Y&@")L\T`E[F"`-'L82*_/E6Y&@"M[&$"(1Y6N>=@U[F"`-.Y"`"I
MN1H`C>Q:.[\E5>S3(K\^5>Q:(#H%5NS3`B$>5KGGT):Y@@":N0@`A>,0\=@`
M!.PX(+\`5>Q8.[\E5<(:;MGKH>Q3`#H%5KD:`!>Y&@`9[)HBOSY5N0@`%>R:
M`B$>5N.@\>``!+GGD'W"JF[9ZZ&Y@@"'N1H`INQA(+\`5>P1.[\E5>P6`#H%
M5KD:`*CC@/'H``2Y"`"APHJ/&[S<ZQ,``@`,N1H`C>P3`"$>5NS1(+\`5;GD
MT%FSP0`H[#H[OR55[(H@OP!5N>80J;F``*:Y@0"EL\T`4N-P\?``!,)ZCQN\
MW.PX`#H%5KD(`*6Y!`!7XW#Q^``$N1H`6<)ZCQN\W.N6``(`#.R6`"$>5KGD
MT&FY@0`9N>C0U[F``!BY@0`6N0@`%;D(`*.SP0!M[#H@OP!5[*H[OR55[*,`
M.@56N0@`H>L8``(`#.P8`"$>5NS1(+\`5;GDT%GL:B"_`%7LBCN_)56YYA"I
MN8``H[F!`*6SS0!6[(8`.@56XW#R```$N0@`I;D(`*C">H\;O-SK@P`"``RY
M!`!7[(,`(1Y6N1H`6>PZ.[\E5>R:(+\`5;F!`!BYY-"HN8``%KF!`!JY"``5
M[#D`.@56XW#R"``$N0@`,<)ZCQN\W.L6``(`#+GHT-?L%@`A'E;L82"_`%6Y
MY&!8L\$`/;GF$-BY@`#9N8$`U;/-`%/L<R"_`%7L,SN_)57L-P`Z!5:Y"`#5
MN0@`T^LY``(`#.PY`"$>5KGD8).Y@0`3XZ#R$``$N8``%\*JCQN\W+F!`!FY
M!`!:N1H`6.R-(+\`5;D(`!7LW3N_)57LV``Z!5:Y"`#1[)T@OP!5ZQ<``@`,
M[!<`(1Y6XW#R&``$PGJ/&[S<N>A@9^QQ(+\`5;GD<%.YYA"CL\$`=KF``*BY
M@0"EL\T`5^S=.[\E5>-@\B``!+D(`*7LV0`Z!5;":H\;O-RY"`#:N00`5NRM
M(+\`5;D:`%/LW3N_)57K.``"``SLV@`Z!5;L.``A'E:YYC"!N>1P$[F``(FY
M@0"!ZQD``@`,N0@`A>P9`"$>5KD(`(WLT2"_`%6YY-!3N>80D^-@\B@`!+F`
M`)K":H\;O-RY@0"5N0@`9[/!`":SS0!2['@@OP!5XV#R,``$N0@`E<)JCQN\
MW.R(.[\E5;D$`%;LAP`Z!5:Y&@!3N>B`.>N:``(`#.R:`"$>5KGDT*FY@0`9
MN8``%[F!`!JY"``5[(,@OP!5[&,[OR55XS#R.``$[&@`.@56PCJ/&[S<N0@`
M8>L7``(`#.P7`"$>5NQQ(+\`5;GD<%FYZ-#3N>80.;/!`&VY@``XN8$`-;/-
M`%;CT/)```3"VH\;O-SLIB"_`%6Y"``U[&8[OR55N00`7>QJ`#H%5KD:`%GC
MT/)(``3KF``"``S"VH\;O-SLF``A'E:YY'")N8$`&;GH<'VY@``:N8$`&+D(
M`!6Y"``VL\$`-^QC(+\`5>PS.[\E5>PV`#H%5KGH,%'K&@`"``SL&@`A'E;L
MT2"_`%6YY-!YN>80J;F``*:Y@0"GL\T`<^PU(+\`5>R%.[\E5;D(`*?L@P`Z
M!5:Y"`"HXU#R4``$['H@OP!5[(H[OR55PEJ/&[S<XZ#R6``$N1H`6<*JCQN\
MW.N6``(`#.R6`"$>5KGDT&FY@0`9N>C0VKF``!.Y@0`6N0@`%>R'`#H%5K/!
M`'VY"`"!ZQ,``@`,[!,`(1Y6[-$@OP!5N>306;GF$*FY@`"GN8$`I;/-`%?L
M:""_`%7L.#N_)56Y"`"E[#8`.@56XX#R8``$PHJ/&[S<N00`6+D:`%GKEP`"
M``SLEP`A'E:YY-!YN8$`&;F``!:Y@0`7N0@`%;D(`*/C@/)H``3L.B"_`%7"
MBH\;O-SLJCN_)57LHP`Z!5:Y"`"AZQ8``@`,[!8`(1Y6[&$@OP!5N>1@6>QZ
M(+\`5;GHT-CLBCN_)56SP0`MN>80J;F``*.Y@0"EL\T`4NR'`#H%5N/0\G``
M!+D(`*7"VH\;O-RY"`"HN00`7;D:`%GLVB"_`%7KDP`"``SLDP`A'E;L.CN_
M)56YY&")N8$`&>P]`#H%5KF``!?CH/)X``2Y@0`8PJJ/&[S<N0@`%;GH8%JY
M"``Q[&,[OR55[&,@.@56ZQ<``@`,L\$`9NP7`"$>5N-@\H``!.R!(+\`5;GF
M$'FYY("IPFJ/&[S<N1H`:;/-`):Y@`!]N8$`>KD(`'6YZ)"7[%D[OR55[%D@
M.@56L\$`%NM]``(`#.Q]`"$>5KD$`-6SS0!1N>2`I^-@\H@`!,)JRF+!UKGH
M@(;`.@````"Y@0`7L\$`.+F``!/K@P`"``RY@0`:[(,`(1Y6N0@`%;/-`&.Y
M"``=XZ#RD``$N>>`U\*JRF+!UKF"`-FY&@"G['DBOSY5['D"(1Y6XY#RF``$
MPIK*8L'6N1H`F+/!`%JSP0`)L\T`E;D:`&WL,3N_)57L,2`Z!5:Y"``V[%,[
MOR55[%,@.@56N>=PJ+F"`*&Y&@":N0@`E;/-`%#L82*_/E7L80(A'E:YYV#7
MN8(`T^P9.[\E5;D:`%WL&2`Z!5:Y"``5[*$[OR55[*$@.@56L\$`*K/-`-+C
M@/*@``3CH/*H``3"BLIBP=;"JLIBP=:Y&@"'N1H`INQS(K\^5>QS`B$>5KGG
M<#;L:2*_/E6Y@@`Y[&D"(1Y6N1H`@[GG8%>Y"`"-N8(`4>R8.[\E5;D:`*7L
MF"`Z!5:Y"`"I[-H[OR55[-H@.@56[)$BOSY5XS#RL``$[)$"(1Y6PCK*8L'6
MN>>05KD:`#>Y@@!8N1H`-;D(`#WLTSN_)57LTR`Z!5;C$/*X``2SP0`=PAK*
M8L'6X]#RP``$N1H`%L+:RF+!UNQH(K\^5;D:`-GL:`(A'E:YYV")L\T`D;F"
M`(KL>B*_/E6Y&@`8['H"(1Y6N0@`&;GG<(;L43N_)56Y@@"#[%$@.@56XZ#R
MR``$PJK*8L'6N1H`IKD$`&WLTR*_/E6Y&@!HN0@`9>S3`B$>5KGGT#>Y@@`Q
M[%8[OR55N1H`H^Q6(#H%5KD(`*7L.CN_)57L.B`Z!5;C@/+0``3"BLIBP=:Y
M&@"'['$BOSY5['$"(1Y6XQ#RV``$N>=P7<(:RF+!UKF"`%:Y&@`=N1H`A>S6
M(K\^5;D(`(/LU@(A'E;L.#N_)56YY]!G[#@@.@56N8(`:KD:`!:Y"``3[#HB
MOSY5[#H"(1Y6N><P;;F"`&CL43N_)57CD/+@``3L42`Z!5;"FLIBP=:Y&@"7
MN1H`ENQH(K\^5;D(`)7L:`(A'E;LB3N_)57LB2`Z!5:YYV!SL\$`2..`\O``
M!,**RF+!UKD:`(.SS0`TN8(`<>.@\N@`!,*JRF+!UKD:`*VY&@"G['$BOSY5
MN0@`H^QQ`B$>5NQ:.[\E5;GG<-;L6B`Z!5:Y@@#9XQ#R^``$N1H`C<(:RF+!
MUKD(`(6Y&@`6[&DBOSY5[&D"(1Y6[)@[OR55N>=@5^R8(#H%5KF"`%JY&@`5
MN0@`&>S1.[\E5>S1(#H%5NR:(K\^5>,P\P``!.R:`B$>5L(ZRF+!UKGGD%:Y
M&@`WN8(`6+D:`#6Y"``][-,[OR55[-,@.@56XZ#S"``$L\$`7<*JRF+!UN/0
M\Q``!+D:`*;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6N>=@B;/-`)6Y@@"!N1H`
MJ.R!(K\^5>R!`B$>5KGG@':Y@@!SN0@`J;D:`-?L6CN_)57L<R*_/E7L6B`Z
M!5;L<P(A'E:Y!``WXS`@(``(P#H`````XS`@(``DXQ#S&``$PAK*8L'6N1H`
M%KGH4&VYYW#8[)8@OP!5N>>@/>Q6.[\E5;D:`!/L60`Z!5:Y"``5[-HBOSY5
MZUD``@`,[-H"(1Y6[%D`(1Y6N>?0-[D(`%2YZ`!]P%H`````XU`@$``DN>=@
M`\!Z`````.-P(!@`).QA(+\`5>.@\R``!,*JRF+!UKD(`.JY&@#H[($[OR55
MN1H`X.R&`#H%5N,0\*``!+D(`.BY"``6P.H`````X^`@```DP!H`````XQ`@
M"``DU0?S*+`HIW0`"NMO\V``!`?^N00`?J?T]07`Y?__X3P'!P<'!P?K[_!P
M`"2G*0"`X_#_8/]QP.7__^#>P#%G12,!P`_OS:N)XS`@```DXP`@"``DP$^8
MNMS^P%$0,E1VXT`@$``DXU`@&``DP#_#TN'PY4@@*```XS`@(``DY4@@,```
MY4P@>```Z^_Q$``$!_X'!P<'ZV_P,``DZQ0``P`-XU`@*``$N00`<KD$`+2Y
M"``5XT`@,``$[`$@OP!5["0``0#9N3$`4;GB($+C\/]8_W'C`'`H`"3K:P`=
M``RYZ$"&XX!P,``DN00`T^,P<'@`$J=T`&1!8'`X[+P`.#]^[%O_P`#8[)T`
M0`#9ZX4`!@#>IXH``1)5IT@``;GR4(1!$'!XN00`K>,0\*``)+DA`&JGI``U
MXP#PH``$[`H`-R!EN00`V=(_8`"@`+D$`">GNO_`IZL`0,#E___T%KD4`+NG
MFP!`IX;_Y+DA`&VG1``@I\0`!KGHL"VY84!BN00`/;D$`":Y!`!+P.7__]_3
M4+!P>.MO\-@`!`?^N00`V:?$_]/L:?_1H&6G]``!N>BP-KEA0-.G]/_DIZ@`
M0!NC&:M!8'`XN?(PJ[D$`":Y&``CN10`2NPM`"*@9;GH0.*YZ$"=N6%`WKD$
M`#T8VL#E___?H5K0<'A0T'!X[-;_S$!^N00`)QNZN00`V<#E___SO+D4`+NG
M]/]RN>A`G>PM_^7`9;EA0"FG]/_@ZX_P0``DN00`L^.`,"@`!..0,#``!.P8
M.K\]5>/P_V#_<;D4`#%!0[`XDH!``*<:``&Y!`"BN10`(4$RL#CL'`!).'ZG
M2`!`N?D0).Q!``J`=J<J__^Y%@`2QA````!+N00`*\#E___S>M<WL#BP.*<Y
M``#L.0`'8%7L.0@/8%7L.1`78%7L.1@?(%6Y!``K[(,`'P!5XX"P<``DP.7_
M__->T@.@`+`$N00`*](#H`2P#-(#H`BP%-(#H`RP'-(#H!"P).N/\.``!,#T
M___B+:<(`#BY^1!0[`'_S(!VIUK__[D6`.7&X`````BG]/_"UP`P`#``UP`P
M`#``!P<'!^OO\'``)+D$``^G^_]@XP#P```DZ^_Q$``$!_X`````)7,O)7,`
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4``!E>&4`+W!R;V,O)6DO)7,`+@!005)?5$5-4```4$%27U!23T=.04U%
M```Z`"\`4$523#5,24(``%!%4DQ,24(`4$523#5/4%0``%!%4DQ)3P``4$%2
M7TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`
M4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U01$E2
M`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M```Q`&QS965K(&9A:6QE9```<F5A9"!F86EL960`3$1?3$E"4D%265]0051(
M`%-94U1%30``)3`R>```<&%R+0``)7,E<R5S)7,``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S
M92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`
M`'!A<FP``"YP87(``'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,``!@`<&5R;```,`!005(Z.E!A
M8VME<CHZ5D524TE/3@``,2XP-C,`56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"UE```M+0``55-%4@``
M55-%4DY!344``%1%35!$25(`5$U0`"]T;7```&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*
M0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S
M971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`]
M(#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?
M<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V
M-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S
M(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@
M(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI
M;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L
M("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H
M*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E
M='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U
M<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@
M)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E
M<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@
M:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![
M("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER
M("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN
M,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@
M)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN
M(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R
M7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF
M:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE
M)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D
M8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<
M7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G
M;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ
M<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D
M<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*
M;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?
M1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@
M9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E
M(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O
M<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!
M4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]
M"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T
M:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N
M92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD[
M"FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O
M=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@
M)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O
M;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A
M<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II
M9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U
M;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE
M86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D
M969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS
M965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H
M95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA
M;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F
M9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN
M86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*
M;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?
M5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q
M6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI
M<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A
M8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN
M9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!0
M05(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![
M(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@
M>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H
M.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U
M:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*
M?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP
M(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6
M>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@
M*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F
M:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E
M<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D
M/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I
M;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE
M;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]
M"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?
M9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%
M04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@
M;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O
M<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`[
M"FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S
M"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C
M86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M
M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M
M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*
M)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F
M:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT
M<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T
M96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I
M;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N
M;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E
M<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D
M+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]
M7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH`````````<&5R;'AS:2YC``!#04-(10```````````1L#.P```-0`
M```9__^#J```!4#__X>P````\/__B(````%`__^)$````7#__XIP```!J/__
MC/````'H__^-:````B3__XV@```"./__CL@```)\__^.T````I#__Y%````"
MT/__D7@```+\__^2X````T#__YAP```#=/__F/````.D__^9:````]#__YM0
M```$%/__FX````0T__^<0```!'#__Z*````$P/__I.@```3\__^EN```!8#_
M_[Q8```%P/__O,@```7D__^^8```!B``````````%``````!>E(``7@.`1L,
M#Z`!````````3````!S__X:X````S@!,A@Z'#8@,B0N*"HL)C`B-!XX&CP5&
M#L`"`HP*S\[-S,O*R<C'Q@Z@`4(+7`K/SLW,R\K)R,?&#J`!0@L````````L
M````;/__AS@```"0`$:*"HL)C`B-!XX&CP5&#M@#`GP*S\[-S,O*#J`!0@L`
M```T````G/__AY@```%@`$:(#(D+B@J+"8P(C0>.!H\%1@[8`W8*S\[-S,O*
MR<@.H`%""P```````#P```#4__^(P````H``1H8.APV(#(D+B@J+"8P(C0>.
M!H\%1@[8`@,!3@K/SLW,R\K)R,?&#J`!0@L````````X```!%/__BP````!T
M`$R&#H<-B`R)"XH*BPF,"(T'C@:/!48.R`("8,_.S<S+RLG(Q\8.H`$`````
M```0```!4/__BSP````X`````````$````%D__^+8````20`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@Z@(4P.H$%,#M!"`N0*S\[-S,O*R<C'Q@Z@`4(+````
M$````:C__XQ$````!@`````````\```!O/__C#@```)L`$:&#H<-B`R)"XH*
MBPF,"(T'C@:/!48.H"%,#N@C`GH*S\[-S,O*R<C'Q@Z@`4(+````*````?S_
M_XYH````-@!*BPF,"(T'C@:/!4H.P`)<S\[-S,L.H`$```````!````"*/__
MCG0```%B`$:*"HL)C`B-!XX&CP5&#J`A3`[((@+T"L_.S<S+R@Z@`4(+7`K/
MSLW,R\H.H`%&"P```````#````)L__^/F```!8P`1HH*BPF,"(T'C@:/!48.
MT`(#!4H*S\[-S,O*#J`!1@L````````L```"H/__E/0```"``$R+"8P(C0>.
M!H\%1@[0`@)>"L_.S<S+#J`!0@L````````H```"T/__E40```!T`%R&#H<-
MB`R)"XH*BPF,"(T'C@:/!48.Z`(``````$````+\__^5D````>@`1H@,B0N*
M"HL)C`B-!XX&CP5&#`Z@@018#0]&#M""!`,!D@K/SLW,R\K)R`Z@`4(+````
M````'````T#__Y<T````+`!&C@:/!48.P`)>S\X.H`$````X```#8/__ET0`
M``#``$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.T`("5`K/SLW,R\K)R,?&#J`!
M1@L```!,```#G/__E\@```8\`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.@`4#
M`F`*S\[-S,O*R<C'Q@Z@`4(+`P*F"L_.S<S+RLG(Q\8.H`%&"P```#@```/L
M__^=N````F8`1H<-B`R)"XH*BPF,"(T'C@:/!48.T`(#`;X*S\[-S,O*R<C'
M#J`!0@L``````$````0H__^?Y````-``1HD+B@J+"8P(C0>.!H\%1@[0`@)>
M"L_.S<S+RLD.H`%""P)8"L_.S<S+RLD.H`%&"P``````/```!&S__WY@```"
M@`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#N@"`P'`"L_.S<S+RLG(Q\8.H`%"
M"P```````#P```2L__^@,```%IH`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0
M!P,6?@K/SLW,R\K)R,?&#J`!0@L````````@```$[/__MI````!L`$J.!H\%
M1@[``@):S\X.H`$````````X```%$/__MMP```&8`%*&#H<-B`R)"XH*BPF,
M"(T'C@:/!6P.R`("R`K/SLW,R\K)R,?&#J`!0@L````T```%3/__N#@```#\
M`$:(#(D+B@J+"8P(C0>.!H\%7`[``@*H"L_.S<S+RLG(#J`!1@L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````B^````````"*0``````````$````````"P0``
M```````!`````````LP`````````'0````````/^``````````P````````8
M$``````````-````````6N@`````````&0```````+O(`````````!L`````
M````"``````````:````````N]``````````'``````````(`````&___O4`
M```````">``````````%````````#"@`````````!@````````-8````````
M``H````````$'``````````+`````````!@`````````%0``````````````
M``````,```````"]N``````````"````````!2@`````````%``````````'
M`````````!<````````2Z``````````'````````$$@`````````"```````
M``*@``````````D`````````&``````````>``````````@`````;___^P``
M```(```!`````&____D`````````$```````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````N]@`````````````````````````````&%H`
M```````8>@```````!B:````````&+H````````8V@```````!CZ````````
M&1H````````9.@```````!E:````````&7H````````9F@```````!FZ````
M````&=H````````9^@```````!H:````````&CH````````:6@```````!IZ
M````````&IH````````:N@```````!K:````````&OH````````;&@``````
M`!LZ````````&UH````````;>@```````!N:````````&[H````````;V@``
M`````!OZ````````'!H````````<.@```````!Q:````````''H````````<
MF@```````!RZ````````'-H````````<^@```````!T:````````'3H`````
M```=6@```````!UZ````````'9H````````=N@```````!W:````````'?H`
M```````>&@```````!XZ````````'EH````````>>@```````!Z:````````
M'KH````````>V@```````![Z````````'QH`````````````````````````
M```````````````8$```````````````````````````````````````````
M```````````````````?,```````````````````6N@`````````````````
M``````````````````````#```I005(N<&T*``````````````````!=]```
M`````%M0``````````````````!;\````````%OT````````7>@```````!;
M5@```````%WP``````````````````!=V````````%W>````````````````
M``!=^D=#0SH@*$%L<&EN92`Q-"XS+C`I(#$T+C,N,```+G-H<W1R=&%B`"YN
M;W1E+F=N=2YB=6EL9"UI9``N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```
M````````````````````````````````````````````````````````````
M``````````````````````````````````L````'``````````(````````"
M.`````````(X`````````"0````````````````````$```````````````>
M`````0`````````"`````````EP````````"7``````````8````````````
M`````````0``````````````)F____8``````````@````````)X````````
M`G@`````````W`````0```````````````@``````````````#`````+````
M``````(````````#6`````````-8````````"-`````%`````@`````````(
M`````````!@````X`````P`````````"````````#"@````````,*```````
M``0<`````````````````````0``````````````0`````0``````````@``
M`````!!(````````$$@````````"H`````0```````````````@`````````
M&````$H````$`````````$(````````2Z````````!+H````````!2@````$
M````$@`````````(`````````!@```!4`````0`````````&````````&!``
M```````8$``````````<`````````````````````@``````````````3P``
M``$`````````!@```````!@L````````&"P````````'````````````````
M``````0`````````(````%H````!``````````8````````?,````````!\P
M````````.[@````````````````````(``````````````!@`````0``````
M```&````````6N@```````!:Z``````````<`````````````````````@``
M````````````9@````$``````````@```````%L(````````6P@```````!`
M@`````````````````````@``````````````&X````!``````````(`````
M``";B````````)N(`````````-0````````````````````$````````````
M``!\`````0`````````"````````G&````````"<8`````````6$````````
M````````````"```````````````A@````X``````````P```````+O(````
M````J\@`````````"`````````````````````@`````````"````)(````/
M``````````,```````"[T````````*O0``````````@`````````````````
M```(``````````@```">````!@`````````#````````N]@```````"KV```
M``````'@````!0``````````````"``````````0````IP````$`````````
M`P```````+VX````````K;@````````"2`````````````````````@`````
M````"````*P````!``````````,```````#``````````+```````````(``
M```````````````````(``````````````"R````"``````````#````````
MP(````````"P@`````````!8````````````````````"```````````````
MMP````$`````````,```````````````````L(``````````'```````````
M``````````$``````````0````$````#````````````````````````````
C`+"<`````````,`````````````````````!````````````
